@@ -41,10 +41,7 @@ let input_int ic =
   let i1 = input_int16 ic in
   i0 lor (i1 lsl 16)
 
-let input_string4 ic =
-  let s = String.create 4 in
-  really_input ic s 0 4;
-  s
+let input_string4 ic = really_input_string ic 4
 
 let print_string4 v s =
   lprintf "%s :" v;
@@ -230,7 +227,7 @@ let rec page_seek ic s pos =
     else begin
       really_input ic s 0 4;
       seek_in ic (pos_in ic - 3);
-      if s = "OggS"
+      if Bytes.unsafe_to_string s = "OggS"
         then seek_in ic (pos_in ic + 3)
         else page_seek ic s pos
   end
@@ -278,12 +275,10 @@ let rec next_ogg_stream ic ogg_infos str stream_number =
   lprintf "Stream Serial Number: %0.f\n" stream_number;
 *)
   seek_in ic (pos+24);
-  let content_type = String.create 1 in
-  really_input ic content_type 0 1;
+  let content_type = really_input_string ic 1 in
   let content_type = int_of_char content_type.[0] in
   seek_in ic (pos+25);
-  let stream_type = String.create 8 in
-  really_input ic stream_type 0 8;
+  let stream_type = really_input_string ic 8 in
   let stream_type = normalize_stream_type stream_type content_type in
   incr stream_number;
   let pos = pos_in ic in
@@ -299,8 +294,7 @@ let rec next_ogg_stream ic ogg_infos str stream_number =
     | OGG_THEORA_STREAM -> get_ogg_theora_info ic ogg_infos str stream_number
 
 and get_ogg_video_info  ic ogg_infos str sizeof_packet stream_number =
-  let s = String.create sizeof_packet in
-  really_input ic s 0 sizeof_packet;
+  let s = really_input_string ic sizeof_packet in
   let codec = String.lowercase (String.sub s 0 4) in
   let time_unit = read64 (String.sub s 8 8) in
   let video_width =
@@ -326,8 +320,7 @@ and get_ogg_video_info  ic ogg_infos str sizeof_packet stream_number =
   next_ogg_stream ic ogg_infos str stream_number
 
 and get_ogg_audio_info  ic ogg_infos str sizeof_packet stream_number =
-  let s = String.create sizeof_packet in
-  really_input ic s 0 sizeof_packet;
+  let s = really_input_string ic sizeof_packet in
   let codec = get_audio_codec (String.sub s 0 4) in
   let sample_per_unit = read64 (String.sub s 16 8) in
   let channels =
@@ -359,8 +352,7 @@ and get_ogg_audio_info  ic ogg_infos str sizeof_packet stream_number =
 
 and get_ogg_vorbis_info  ic ogg_infos str stream_number =
   seek_in ic (pos_in ic - 2); (* ogm sets 8 octets in the common header as vorbis uses 6 octects for 'vorbis' *)
-  let s = String.create 22 in
-  really_input ic s 0 22;
+  let s = really_input_string ic 22 in
   let version = read32 (String.sub s 0 4) in
   let audio_channels = int_of_char s.[4] in
   let sample_rate = read32 (String.sub s 5 4) in
@@ -389,8 +381,7 @@ and get_ogg_vorbis_info  ic ogg_infos str stream_number =
 
 and get_ogg_theora_info  ic ogg_infos str stream_number =
   seek_in ic (pos_in ic - 2); (* ogm sets 8 octets in the common header as theora uses 6 octects for 'theora' *)
-  let s = String.create 34 in
-  really_input ic s 0 34;
+  let s = really_input_string ic 34 in
   let vmaj = int_of_char s.[0] in
   let vmin = int_of_char s.[1] in
   let vrev = int_of_char s.[2] in
@@ -451,7 +442,7 @@ and get_ogg_index_info ic ogg_infos str stream_number =
 
 let search_info_ogg ic =
     let stream_number = ref 0 in
-    let str = String.create 4 in
+    let str = Bytes.create 4 in
     let ogg_infos = ref [] in
     (* make sure the current reading position is at the file beginning *)
     seek_in ic 0;
@@ -700,18 +691,18 @@ module Bchunk =
 #define VERSION "1.1.1"
 #define USAGE "Usage: bchunk [-v] [-p (PSX)] [-w (wav)] [-s (swabaudio)]\n" \
         "         <image.bin> <image.cue> <basename>\n" \
-	"Example: bchunk foo.bin foo.cue foo\n" \
-	"  -v  Verbose mode\n" \
-	"  -p  PSX mode: truncate MODE2/2352 to 2336 bytes instead of normal 2048\n" \
-	"  -w  Output audio files in WAV format\n" \
-	"  -s  swabaudio: swap byte order in audio tracks\n"
-	
+        "Example: bchunk foo.bin foo.cue foo\n" \
+        "  -v  Verbose mode\n" \
+        "  -p  PSX mode: truncate MODE2/2352 to 2336 bytes instead of normal 2048\n" \
+        "  -w  Output audio files in WAV format\n" \
+        "  -s  swabaudio: swap byte order in audio tracks\n"
+        
 #define VERSTR	"binchunker for Unix, version " VERSION " by Heikki Hannikainen <hessu@hes.iki.fi>\n" \
-		"\tCreated with the kind help of Bob Marietta <marietrg@SLU.EDU>,\n" \
-		"\tpartly based on his Pascal (Delphi) implementation.\n" \
-		"\tSupport for MODE2/2352 ISO tracks thanks to input from\n" \
-		"\tGodmar Back <gback@cs.utah.edu> and Colas Nahaboo <Colas@Nahaboo.com>\n" \
-		"\tReleased under the GNU GPL, version 2 or later (at your option).\n\n"
+                "\tCreated with the kind help of Bob Marietta <marietrg@SLU.EDU>,\n" \
+                "\tpartly based on his Pascal (Delphi) implementation.\n" \
+                "\tSupport for MODE2/2352 ISO tracks thanks to input from\n" \
+                "\tGodmar Back <gback@cs.utah.edu> and Colas Nahaboo <Colas@Nahaboo.com>\n" \
+                "\tReleased under the GNU GPL, version 2 or later (at your option).\n\n"
 
 #define CUELLEN 1024
 #define SECTLEN 2352
@@ -742,18 +733,18 @@ module Bchunk =
 
 
 struct track_t {
-	int num;
-	int mode;
-	int audio;
-	char *modes;
-	char *extension;
-	int bstart;
-	int bsize;
-	long startsect;
-	long stopsect;
-	long start;
-	long stop;
-	struct track_t *next;
+        int num;
+        int mode;
+        int audio;
+        char *modes;
+        char *extension;
+        int bstart;
+        int bsize;
+        long startsect;
+        long stopsect;
+        long start;
+        long stop;
+        struct track_t *next;
 };
 
 char *basefile = NULL;
@@ -770,51 +761,51 @@ int towav = 0;
 
 void parse_args(int argc, char *argv[])
 {
-	int s;
-	
-	while ((s = getopt(argc, argv, "swvp?h")) != -1) {
-		switch (s) {
-			case 'v':
-				verbose = 1;
-				break;
-			case 'w':
-				towav = 1;
-				break;
-			case 'p':
-				psxtruncate = 1;
-				break;
-			case 's':
-				swabaudio = 1;
-				break;
-			case '?':
-			case 'h':
-				fprintf(stderr, "%s", USAGE);
-				exit(0);
-		}
-	}
+        int s;
+        
+        while ((s = getopt(argc, argv, "swvp?h")) != -1) {
+                switch (s) {
+                        case 'v':
+                                verbose = 1;
+                                break;
+                        case 'w':
+                                towav = 1;
+                                break;
+                        case 'p':
+                                psxtruncate = 1;
+                                break;
+                        case 's':
+                                swabaudio = 1;
+                                break;
+                        case '?':
+                        case 'h':
+                                fprintf(stderr, "%s", USAGE);
+                                exit(0);
+                }
+        }
 
-	if (argc - optind != 3) {
-		fprintf(stderr, "%s", USAGE);
-		exit(1);
-	}
-	
-	while (optind < argc) {
-		switch (argc - optind) {
-			case 3:
-				binfile = strdup(argv[optind]);
-				break;
-			case 2:
-				cuefile = strdup(argv[optind]);
-				break;
-			case 1:
-				basefile = strdup(argv[optind]);
-				break;
-			default:
-				fprintf(stderr, "%s", USAGE);
-				exit(1);
-		}
-		optind++;
-	}
+        if (argc - optind != 3) {
+                fprintf(stderr, "%s", USAGE);
+                exit(1);
+        }
+        
+        while (optind < argc) {
+                switch (argc - optind) {
+                        case 3:
+                                binfile = strdup(argv[optind]);
+                                break;
+                        case 2:
+                                cuefile = strdup(argv[optind]);
+                                break;
+                        case 1:
+                                basefile = strdup(argv[optind]);
+                                break;
+                        default:
+                                fprintf(stderr, "%s", USAGE);
+                                exit(1);
+                }
+                optind++;
+        }
 }
 
 /*
@@ -823,24 +814,24 @@ void parse_args(int argc, char *argv[])
 
 long time2frames(char *s)
 {
-	int mins = 0, secs = 0, frames = 0;
-	char *p, *t;
-	
-	if (!(p = strchr(s, ':')))
-		return -1;
-	*p = '\0';
-	mins = atoi(s);
-	
-	p++;
-	if (!(t = strchr(p, ':')))
-		return -1;
-	*t = '\0';
-	secs = atoi(p);
-	
-	t++;
-	frames = atoi(t);
-	
-	return 75 * (mins * 60 + secs) + frames;
+        int mins = 0, secs = 0, frames = 0;
+        char *p, *t;
+        
+        if (!(p = strchr(s, ':')))
+                return -1;
+        *p = '\0';
+        mins = atoi(s);
+        
+        p++;
+        if (!(t = strchr(p, ':')))
+                return -1;
+        *t = '\0';
+        secs = atoi(p);
+        
+        t++;
+        frames = atoi(t);
+        
+        return 75 * (mins * 60 + secs) + frames;
 }
 
 /*
@@ -849,52 +840,52 @@ long time2frames(char *s)
 
 void gettrackmode(struct track_t *track, char *modes)
 {
-	static char ext_iso[] = "iso";
-	static char ext_cdr[] = "cdr";
-	static char ext_wav[] = "wav";
-	static char ext_ugh[] = "ugh";
-	
-	track->audio = 0;
-	
-	if (!strcasecmp(modes, "MODE1/2352")) {
-		track->bstart = 16;
-		track->bsize = 2048;
-		track->extension = ext_iso;
-		
-	} else if (!strcasecmp(modes, "MODE2/2352")) {
-		track->extension = ext_iso;
-		if (psxtruncate) {
-			/* PSX: truncate from 2352 to 2336 byte tracks */
-			track->bstart = 0;
-			track->bsize = 2336;
-		} else {
-			/* Normal MODE2/2352 */
-			track->bstart = 24;
-			track->bsize = 2048;
-		}
-		
-	} else if (!strcasecmp(modes, "MODE2/2336")) {
-		/* WAS 2352 in V1.361B still work?
-		 * what if MODE2/2336 single track bin, still 2352 sectors?
-		 */
-		track->bstart = 16;
-		track->bsize = 2336;
-		track->extension = ext_iso;
-		
-	} else if (!strcasecmp(modes, "AUDIO")) {
-		track->bstart = 0;
-		track->bsize = 2352;
-		track->audio = 1;
-		if (towav)
-			track->extension = ext_wav;
-		else
-			track->extension = ext_cdr;
-	} else {
-		printf("(?) ");
-		track->bstart = 0;
-		track->bsize = 2352;
-		track->extension = ext_ugh;
-	}
+        static char ext_iso[] = "iso";
+        static char ext_cdr[] = "cdr";
+        static char ext_wav[] = "wav";
+        static char ext_ugh[] = "ugh";
+        
+        track->audio = 0;
+        
+        if (!strcasecmp(modes, "MODE1/2352")) {
+                track->bstart = 16;
+                track->bsize = 2048;
+                track->extension = ext_iso;
+                
+        } else if (!strcasecmp(modes, "MODE2/2352")) {
+                track->extension = ext_iso;
+                if (psxtruncate) {
+                        /* PSX: truncate from 2352 to 2336 byte tracks */
+                        track->bstart = 0;
+                        track->bsize = 2336;
+                } else {
+                        /* Normal MODE2/2352 */
+                        track->bstart = 24;
+                        track->bsize = 2048;
+                }
+                
+        } else if (!strcasecmp(modes, "MODE2/2336")) {
+                /* WAS 2352 in V1.361B still work?
+                 * what if MODE2/2336 single track bin, still 2352 sectors?
+                 */
+                track->bstart = 16;
+                track->bsize = 2336;
+                track->extension = ext_iso;
+                
+        } else if (!strcasecmp(modes, "AUDIO")) {
+                track->bstart = 0;
+                track->bsize = 2352;
+                track->audio = 1;
+                if (towav)
+                        track->extension = ext_wav;
+                else
+                        track->extension = ext_cdr;
+        } else {
+                printf("(?) ");
+                track->bstart = 0;
+                track->bsize = 2352;
+                track->extension = ext_ugh;
+        }
 }
 
 /*
@@ -903,19 +894,19 @@ void gettrackmode(struct track_t *track, char *modes)
 
 char *progressbar(float f, int l)
 {
-	static char s[80];
-	int i, n;
-	
-	n = l * f;
-	for (i = 0; i < n; i++) {
-		s[i] = '*';
-	}
-	for (; i < l; i++) {
-		s[i] = ' ';
-	}
-	s[i] = '\0';
-	
-	return s;
+        static char s[80];
+        int i, n;
+        
+        n = l * f;
+        for (i = 0; i < n; i++) {
+                s[i] = '*';
+        }
+        for (; i < l; i++) {
+                s[i] = ' ';
+        }
+        s[i] = '\0';
+        
+        return s;
 }
 
 /*
@@ -924,121 +915,121 @@ char *progressbar(float f, int l)
 
 int writetrack(FILE *bf, struct track_t *track, char *bname)
 {
-	char *fname;
-	FILE *f;
-	char buf[SECTLEN+10];
-	long sz, sect, realsz, reallen;
-	char c, *p, *p2, *ep;
-	int32_t l;
-	int16_t i;
-	float fl;
-	
-	if (!(fname = malloc(strlen(bname) + 8))) {
-		fprintf(stderr, "main(): malloc() failed, out of memory\n");
-		exit(4);
-	}
-	sprintf(fname, "%s%2.2d.%s", bname, track->num, track->extension);
-	
-	printf("%2d: %s ", track->num, fname);
-	
-	if (!(f = fopen(fname, "w"))) {
-		fprintf(stderr, " Could not fopen track file: %s\n", strerror(errno));
-		exit(4);
-	}
-	
-	if (fseek(bf, track->start, SEEK_SET)) {
-		fprintf(stderr, " Could not fseek to track location: %s\n", strerror(errno));
-		exit(4);
-	}
-	
-	reallen = (track->stopsect - track->startsect + 1) * track->bsize;
-	if (verbose) {
-		printf("\n mmc sectors %ld->%ld (%ld)", track->startsect, track->stopsect, track->stopsect - track->startsect + 1);
-		printf("\n mmc bytes %ld->%ld (%ld)", track->start, track->stop, track->stop - track->start + 1);
-		printf("\n sector data at %d, %d bytes per sector", track->bstart, track->bsize);
-		printf("\n real data %ld bytes", (track->stopsect - track->startsect + 1) * track->bsize);
-		printf("\n");
-	}
+        char *fname;
+        FILE *f;
+        char buf[SECTLEN+10];
+        long sz, sect, realsz, reallen;
+        char c, *p, *p2, *ep;
+        int32_t l;
+        int16_t i;
+        float fl;
+        
+        if (!(fname = malloc(strlen(bname) + 8))) {
+                fprintf(stderr, "main(): malloc() failed, out of memory\n");
+                exit(4);
+        }
+        sprintf(fname, "%s%2.2d.%s", bname, track->num, track->extension);
+        
+        printf("%2d: %s ", track->num, fname);
+        
+        if (!(f = fopen(fname, "w"))) {
+                fprintf(stderr, " Could not fopen track file: %s\n", strerror(errno));
+                exit(4);
+        }
+        
+        if (fseek(bf, track->start, SEEK_SET)) {
+                fprintf(stderr, " Could not fseek to track location: %s\n", strerror(errno));
+                exit(4);
+        }
+        
+        reallen = (track->stopsect - track->startsect + 1) * track->bsize;
+        if (verbose) {
+                printf("\n mmc sectors %ld->%ld (%ld)", track->startsect, track->stopsect, track->stopsect - track->startsect + 1);
+                printf("\n mmc bytes %ld->%ld (%ld)", track->start, track->stop, track->stop - track->start + 1);
+                printf("\n sector data at %d, %d bytes per sector", track->bstart, track->bsize);
+                printf("\n real data %ld bytes", (track->stopsect - track->startsect + 1) * track->bsize);
+                printf("\n");
+        }
 
-	printf("                                          ");
-	
-	if ((track->audio) && (towav)) {
-		// RIFF header
-		fputs("RIFF", f);
-		l = htolel(reallen + WAV_DATA_HLEN + WAV_FORMAT_HLEN + 4);
-		fwrite(&l, 4, 1, f);  // length of file, starting from WAVE
-		fputs("WAVE", f);
-		// FORMAT header
-		fputs("fmt ", f);
-		l = htolel(0x10);     // length of FORMAT header
-		fwrite(&l, 4, 1, f);
-		i = htoles(0x01);     // constant
-		fwrite(&i, 2, 1, f);
-		i = htoles(0x02);	// channels
-		fwrite(&i, 2, 1, f);
-		l = htolel(44100);	// sample rate
-		fwrite(&l, 4, 1, f);
-		l = htolel(44100 * 4);	// bytes per second
-		fwrite(&l, 4, 1, f);
-		i = htoles(4);		// bytes per sample
-		fwrite(&i, 2, 1, f);
-		i = htoles(2*8);	// bits per channel
-		fwrite(&i, 2, 1, f);
-		// DATA header
-		fputs("data", f);
-		l = htolel(reallen);
-		fwrite(&l, 4, 1, f);
-	}
-	
-	realsz = 0;
-	sz = track->start;
-	sect = track->startsect;
-	fl = 0;
-	while ((sect <= track->stopsect) && (fread(buf, SECTLEN, 1, bf) > 0)) {
-		if (track->audio) {
-			if (swabaudio) {
-				/* swap low and high bytes */
-				p = &buf[track->bstart];
-				ep = p + track->bsize;
-				while (p < ep) {
-					p2 = p + 1;
-					c = *p;
-					*p = *p2;
-					*p2 = c;
-					p += 2;
-				}
-			}
-		}
-		if (fwrite(&buf[track->bstart], track->bsize, 1, f) < 1) {
-			fprintf(stderr, " Could not write to track: %s\n", strerror(errno));
-			exit(4);
-		}
-		sect++;
-		sz += SECTLEN;
-		realsz += track->bsize;
-		if (((sz / SECTLEN) % 500) == 0) {
-			fl = (float)realsz / (float)reallen;
-			printf("\b\b\b\b\b\b\b\b\b\b\b\b\b\b\b\b\b\b\b\b\b\b\b\b\b\b\b\b\b\b\b\b\b\b\b\b\b\b\b\b\b\b%4ld/%-4ld MB  [%s] %3.0f %%", realsz/1024/1024, reallen/1024/1024, progressbar(fl, 20), fl * 100);
-			fflush(stdout);
-		}
-	}
-	
-	fl = (float)realsz / (float)reallen;
-	printf("\b\b\b\b\b\b\b\b\b\b\b\b\b\b\b\b\b\b\b\b\b\b\b\b\b\b\b\b\b\b\b\b\b\b\b\b\b\b\b\b\b\b%4ld/%-4ld MB  [%s] %3.0f %%", realsz/1024/1024, reallen/1024/1024, progressbar(1, 20), fl * 100);
-	fflush(stdout);
-	
-	if (ferror(bf)) {
-		fprintf(stderr, " Could not read from %s: %s\n", binfile, strerror(errno));
-		exit(4);
-	}
-	
-	if (fclose(f)) {
-		fprintf(stderr, " Could not fclose track file: %s\n", strerror(errno));
-		exit(4);
-	}
-	
-	printf("\n");
-	return 0;
+        printf("                                          ");
+        
+        if ((track->audio) && (towav)) {
+                // RIFF header
+                fputs("RIFF", f);
+                l = htolel(reallen + WAV_DATA_HLEN + WAV_FORMAT_HLEN + 4);
+                fwrite(&l, 4, 1, f);  // length of file, starting from WAVE
+                fputs("WAVE", f);
+                // FORMAT header
+                fputs("fmt ", f);
+                l = htolel(0x10);     // length of FORMAT header
+                fwrite(&l, 4, 1, f);
+                i = htoles(0x01);     // constant
+                fwrite(&i, 2, 1, f);
+                i = htoles(0x02);	// channels
+                fwrite(&i, 2, 1, f);
+                l = htolel(44100);	// sample rate
+                fwrite(&l, 4, 1, f);
+                l = htolel(44100 * 4);	// bytes per second
+                fwrite(&l, 4, 1, f);
+                i = htoles(4);		// bytes per sample
+                fwrite(&i, 2, 1, f);
+                i = htoles(2*8);	// bits per channel
+                fwrite(&i, 2, 1, f);
+                // DATA header
+                fputs("data", f);
+                l = htolel(reallen);
+                fwrite(&l, 4, 1, f);
+        }
+        
+        realsz = 0;
+        sz = track->start;
+        sect = track->startsect;
+        fl = 0;
+        while ((sect <= track->stopsect) && (fread(buf, SECTLEN, 1, bf) > 0)) {
+                if (track->audio) {
+                        if (swabaudio) {
+                                /* swap low and high bytes */
+                                p = &buf[track->bstart];
+                                ep = p + track->bsize;
+                                while (p < ep) {
+                                        p2 = p + 1;
+                                        c = *p;
+                                        *p = *p2;
+                                        *p2 = c;
+                                        p += 2;
+                                }
+                        }
+                }
+                if (fwrite(&buf[track->bstart], track->bsize, 1, f) < 1) {
+                        fprintf(stderr, " Could not write to track: %s\n", strerror(errno));
+                        exit(4);
+                }
+                sect++;
+                sz += SECTLEN;
+                realsz += track->bsize;
+                if (((sz / SECTLEN) % 500) == 0) {
+                        fl = (float)realsz / (float)reallen;
+                        printf("\b\b\b\b\b\b\b\b\b\b\b\b\b\b\b\b\b\b\b\b\b\b\b\b\b\b\b\b\b\b\b\b\b\b\b\b\b\b\b\b\b\b%4ld/%-4ld MB  [%s] %3.0f %%", realsz/1024/1024, reallen/1024/1024, progressbar(fl, 20), fl * 100);
+                        fflush(stdout);
+                }
+        }
+        
+        fl = (float)realsz / (float)reallen;
+        printf("\b\b\b\b\b\b\b\b\b\b\b\b\b\b\b\b\b\b\b\b\b\b\b\b\b\b\b\b\b\b\b\b\b\b\b\b\b\b\b\b\b\b%4ld/%-4ld MB  [%s] %3.0f %%", realsz/1024/1024, reallen/1024/1024, progressbar(1, 20), fl * 100);
+        fflush(stdout);
+        
+        if (ferror(bf)) {
+                fprintf(stderr, " Could not read from %s: %s\n", binfile, strerror(errno));
+                exit(4);
+        }
+        
+        if (fclose(f)) {
+                fprintf(stderr, " Could not fclose track file: %s\n", strerror(errno));
+                exit(4);
+        }
+        
+        printf("\n");
+        return 0;
 }
 
 /*
@@ -1047,120 +1038,120 @@ int writetrack(FILE *bf, struct track_t *track, char *bname)
 
 int main(int argc, char **argv)
 {
-	char s[CUELLEN+1];
-	char *p, *t;
-	int i, idx;
-	struct track_t *tracks = NULL;
-	struct track_t *track = NULL;
-	struct track_t *prevtrack = NULL;
-	struct track_t **prevp = &tracks;
-	
-	FILE *binf, *cuef;
-	
-	printf("%s", VERSTR);
-	
-	parse_args(argc, argv);
-	
-	if (!((binf = fopen(binfile, "r")))) {
-		fprintf(stderr, "Could not open BIN %s: %s\n", binfile, strerror(errno));
-		return 2;
-	}
-	
-	if (!((cuef = fopen(cuefile, "r")))) {
-		fprintf(stderr, "Could not open CUE %s: %s\n", cuefile, strerror(errno));
-		return 2;
-	}
-	
-	printf("Reading the CUE file:\n");
-	
-	/* We don't really care about the first line. */
-	if (!fgets(s, CUELLEN, cuef)) {
-		fprintf(stderr, "Could not read first line from %s: %s\n", cuefile, strerror(errno));
-		return 3;
-	}
-	
-	i = 0;
-	while (fgets(s, CUELLEN, cuef)) {
-		while ((p = strchr(s, '\r')) || (p = strchr(s, '\n')))
-			*p = '\0';
-			
-		if ((p = strstr(s, "TRACK"))) {
-			printf("\nTrack ");
-			if (!(p = strchr(p, ' '))) {
-				fprintf(stderr, "... ouch, no space after TRACK.\n");
-				continue;
-			}
-			p++;
-			if (!(t = strchr(p, ' '))) {
-				fprintf(stderr, "... ouch, no space after track number.\n");
-				continue;
-			}
-			*t = '\0';
-			
-			prevtrack = track;
-			if (!(track = malloc(sizeof(struct track_t)))) {
-				fprintf(stderr, "main(): malloc() failed, out of memory\n");
-				exit(4);
-			}
-			*prevp = track;
-			prevp = &track->next;
-			track->next = NULL;
-			track->num = atoi(p);
-			
-			p = t + 1;
-			printf("%2d: %-12.12s ", track->num, p);
-			track->modes = strdup(p);
-			track->extension = NULL;
-			track->mode = 0;
-			track->audio = 0;
-			track->bsize = track->bstart = -1;
-			track->bsize = -1;
-			track->startsect = track->stopsect = -1;
-			
-			gettrackmode(track, p);
-			
-		} else if ((p = strstr(s, "INDEX"))) {
-			if (!(p = strchr(p, ' '))) {
-				printf("... ouch, no space after INDEX.\n");
-				continue;
-			}
-			p++;
-			if (!(t = strchr(p, ' '))) {
-				printf("... ouch, no space after index number.\n");
-				continue;
-			}
-			*t = '\0';
-			t++;
-			idx = atoi(p);
-			printf(" %s %s", p, t);
-			track->startsect = time2frames(t);
-			track->start = track->startsect * SECTLEN;
-			if (verbose)
-				printf(" (startsect %ld ofs %ld)", track->startsect, track->start);
-			if ((prevtrack) && (prevtrack->stopsect < 0)) {
-				prevtrack->stopsect = track->startsect;
-				prevtrack->stop = track->start - 1;
-			}
-		}
-	}
-	
-	if (track) {
-		fseek(binf, 0, SEEK_END);
-		track->stop = ftell(binf);
-		track->stopsect = track->stop / SECTLEN;
-	}
-	
-	printf("\n\n");
-	
-	
-	printf("Writing tracks:\n\n");
-	for (track = tracks; (track); track = track->next)
-		writetrack(binf, track, basefile);
-		
-	fclose(binf);
-	fclose(cuef);
-	
-	return 0;
+        char s[CUELLEN+1];
+        char *p, *t;
+        int i, idx;
+        struct track_t *tracks = NULL;
+        struct track_t *track = NULL;
+        struct track_t *prevtrack = NULL;
+        struct track_t **prevp = &tracks;
+        
+        FILE *binf, *cuef;
+        
+        printf("%s", VERSTR);
+        
+        parse_args(argc, argv);
+        
+        if (!((binf = fopen(binfile, "r")))) {
+                fprintf(stderr, "Could not open BIN %s: %s\n", binfile, strerror(errno));
+                return 2;
+        }
+        
+        if (!((cuef = fopen(cuefile, "r")))) {
+                fprintf(stderr, "Could not open CUE %s: %s\n", cuefile, strerror(errno));
+                return 2;
+        }
+        
+        printf("Reading the CUE file:\n");
+        
+        /* We don't really care about the first line. */
+        if (!fgets(s, CUELLEN, cuef)) {
+                fprintf(stderr, "Could not read first line from %s: %s\n", cuefile, strerror(errno));
+                return 3;
+        }
+        
+        i = 0;
+        while (fgets(s, CUELLEN, cuef)) {
+                while ((p = strchr(s, '\r')) || (p = strchr(s, '\n')))
+                        *p = '\0';
+                        
+                if ((p = strstr(s, "TRACK"))) {
+                        printf("\nTrack ");
+                        if (!(p = strchr(p, ' '))) {
+                                fprintf(stderr, "... ouch, no space after TRACK.\n");
+                                continue;
+                        }
+                        p++;
+                        if (!(t = strchr(p, ' '))) {
+                                fprintf(stderr, "... ouch, no space after track number.\n");
+                                continue;
+                        }
+                        *t = '\0';
+                        
+                        prevtrack = track;
+                        if (!(track = malloc(sizeof(struct track_t)))) {
+                                fprintf(stderr, "main(): malloc() failed, out of memory\n");
+                                exit(4);
+                        }
+                        *prevp = track;
+                        prevp = &track->next;
+                        track->next = NULL;
+                        track->num = atoi(p);
+                        
+                        p = t + 1;
+                        printf("%2d: %-12.12s ", track->num, p);
+                        track->modes = strdup(p);
+                        track->extension = NULL;
+                        track->mode = 0;
+                        track->audio = 0;
+                        track->bsize = track->bstart = -1;
+                        track->bsize = -1;
+                        track->startsect = track->stopsect = -1;
+                        
+                        gettrackmode(track, p);
+                        
+                } else if ((p = strstr(s, "INDEX"))) {
+                        if (!(p = strchr(p, ' '))) {
+                                printf("... ouch, no space after INDEX.\n");
+                                continue;
+                        }
+                        p++;
+                        if (!(t = strchr(p, ' '))) {
+                                printf("... ouch, no space after index number.\n");
+                                continue;
+                        }
+                        *t = '\0';
+                        t++;
+                        idx = atoi(p);
+                        printf(" %s %s", p, t);
+                        track->startsect = time2frames(t);
+                        track->start = track->startsect * SECTLEN;
+                        if (verbose)
+                                printf(" (startsect %ld ofs %ld)", track->startsect, track->start);
+                        if ((prevtrack) && (prevtrack->stopsect < 0)) {
+                                prevtrack->stopsect = track->startsect;
+                                prevtrack->stop = track->start - 1;
+                        }
+                }
+        }
+        
+        if (track) {
+                fseek(binf, 0, SEEK_END);
+                track->stop = ftell(binf);
+                track->stopsect = track->stop / SECTLEN;
+        }
+        
+        printf("\n\n");
+        
+        
+        printf("Writing tracks:\n\n");
+        for (track = tracks; (track); track = track->next)
+                writetrack(binf, track, basefile);
+                
+        fclose(binf);
+        fclose(cuef);
+        
+        return 0;
 }
 
 
