@@ -493,7 +493,7 @@ let help_string version = Printf.sprintf "
                       ========
 
 Release: %s
-Authors: MLDonkey project, http://www.mldonkey.net/
+Authors: MLDonkey project, http://mldonkey.sf.net
 
 This documentation file is now obsolete. Read the FAQ instead (either
 on the project WEB site or in the FAQ.html file).
@@ -503,9 +503,7 @@ For help, see:
 IRC channel: irc.freenode.net, chat #mldonkey
 
 Web sites:
-http://www.mldonkey.net/         Official site, bug reports
-http://www.mldonkeyworld.com/    English forum
-http://www.mldonkey.org/         German forum
+http://mldonkey.sf.net         Official site
 
 Mailing-lists:
 mldonkey-users@nongnu.org
