@@ -319,8 +319,8 @@ let xpm_mini_refresh =  define_option mldonkey_gui_section (xpm_mini_label M.o_x
 (** {2 Toolbars style} *)
 
 let tb_styles = [ "both", `BOTH ; 
-		  "text", `TEXT ;
-		  "icon", `ICONS ]
+                  "text", `TEXT ;
+                  "icon", `ICONS ]
 
 let tb_styles_rev = List.map
     (fun (a,b) -> (b,a)) tb_styles
@@ -497,7 +497,7 @@ let login = define_option mldonkey_gui_section ["login"]
 let password = define_option mldonkey_gui_section ["password"] 
     (gettext M.h_gui_password) string_option ""
 let port = define_option mldonkey_gui_section ["port"] 
-    (gettext M.h_gui_port) int_option 4001
+    (gettext M.h_gui_port) port_option 4001
 let hostname = define_option mldonkey_gui_section ["hostname"] 
     (gettext M.h_hostname) string_option "localhost"
 
@@ -631,24 +631,24 @@ let gdk_pix i =
     let (default, o) = List.assoc i table in
     match !!o with
       "" -> 
-	GDraw.pixmap_from_xpm_d ~data: default
-	  ~colormap: (Gdk.Color.get_system_colormap ())
-	  () 
+        GDraw.pixmap_from_xpm_d ~data: default
+          ~colormap: (Gdk.Color.get_system_colormap ())
+          () 
     | f ->
-	try
-	  GDraw.pixmap_from_xpm ~file: f
-	    ~colormap: (Gdk.Color.get_system_colormap ())
-	    () 
-	with
-	  _ ->
-	    GDraw.pixmap_from_xpm_d ~data: default
-	      ~colormap: (Gdk.Color.get_system_colormap ())
-	      () 
+        try
+          GDraw.pixmap_from_xpm ~file: f
+            ~colormap: (Gdk.Color.get_system_colormap ())
+            () 
+        with
+          _ ->
+            GDraw.pixmap_from_xpm_d ~data: default
+              ~colormap: (Gdk.Color.get_system_colormap ())
+              () 
   with
     Not_found ->
       GDraw.pixmap_from_xpm_d ~data: Trash_xpm.t
-	~colormap: (Gdk.Color.get_system_colormap ())
-	() 
+        ~colormap: (Gdk.Color.get_system_colormap ())
+        () 
       
 let pixmap i = GMisc.pixmap (gdk_pix i) ()
       
