@@ -40,7 +40,7 @@ let first_name r =
     [] -> gettext M.unknown
   | n :: _ -> n
 
-let shorten_name s = Filename2.shorten !!O.max_result_name_len s
+let shorten_name s = CommonGlobals.shorten s !!O.max_result_name_len
 
 let is_filtered r = false
 (* TODO RESULT
@@ -176,10 +176,10 @@ class box s_num columns () =
 (*
     method remove_extend_search_button =
       match wb_extend_search with
-	None -> ()
+        None -> ()
       |	Some wb -> 
-	  wtool#remove wb#coerce;
-	  wb_extend_search <- None
+          wtool#remove wb#coerce;
+          wb_extend_search <- None
 *)
     
     initializer
