@@ -234,22 +234,22 @@ let color_network_disabled =  define_option mldonkey_gui_section ["colors"; "net
 
 let font_list =  define_option mldonkey_gui_section ["fonts"; "list"]
     ( M.h_font_list) string_option
-     ( if Autoconf.system = "windows" then "-unknown-Tahoma-normal-r-normal-*-*-100-*-*-p-*-iso8859-1"
+     ( if Autoconf.windows then "-unknown-Tahoma-normal-r-normal-*-*-100-*-*-p-*-iso8859-1"
      else "-*-*-*-*-*-*-*-*-*-*-*-*-*-*" )
 
 let font_main_tab =  define_option mldonkey_gui_section ["fonts"; "main_tab"]
     ( M.h_font_main_tab) string_option
-     ( if Autoconf.system = "windows" then "-unknown-Tahoma-normal-r-normal-*-*-100-*-*-p-*-iso8859-1"
+     ( if Autoconf.windows then "-unknown-Tahoma-normal-r-normal-*-*-100-*-*-p-*-iso8859-1"
      else "-*-*-*-*-*-*-*-*-*-*-*-*-*-*" )
 
 let font_networks =  define_option mldonkey_gui_section ["fonts"; "networks"]
     ( M.h_font_networks) string_option
-     ( if Autoconf.system = "windows" then "-unknown-Tahoma-normal-r-normal-*-*-100-*-*-p-*-iso8859-1"
+     ( if Autoconf.windows then "-unknown-Tahoma-normal-r-normal-*-*-100-*-*-p-*-iso8859-1"
      else "-*-*-*-*-*-*-*-*-*-*-*-*-*-*" )
 
 let font_graphic =  define_option mldonkey_gui_section ["fonts"; "graphic"]
     ( M.h_font_graphic)  string_option
-     ( if Autoconf.system = "windows" then "-unknown-Tahoma-normal-r-normal-*-*-80-*-*-p-*-iso8859-1"
+     ( if Autoconf.windows then "-unknown-Tahoma-normal-r-normal-*-*-80-*-*-p-*-iso8859-1"
      else "-*-*-*-*-*-*-*-*-*-*-*-*-*-*" )
 
 (*
@@ -376,8 +376,6 @@ let xpm_nbk_graphs_menu = define_option mldonkey_gui_section (xpm_label M.o_xpm_
 
 let xpm_about = define_option mldonkey_gui_section (xpm_label M.o_xpm_about)
     "" filename_option ""
-let xpm_im = define_option mldonkey_gui_section (xpm_label M.o_xpm_im)
-    "" filename_option ""
 let xpm_settings = define_option mldonkey_gui_section (xpm_label M.o_xpm_settings)
     "" filename_option ""
 let xpm_exit = define_option mldonkey_gui_section (xpm_label M.o_xpm_exit)
@@ -546,8 +544,8 @@ let xpm_mld_tux_off = define_option mldonkey_gui_section (xpm_label M.o_xpm_mld_
 (** {2 Toolbars style} *)
 
 let tb_styles = [ "both", `BOTH ; 
-		  "text", `TEXT ;
-		  "icon", `ICONS ]
+                  "text", `TEXT ;
+                  "icon", `ICONS ]
 
 let tb_styles_rev = List.map
     (fun (a,b) -> (b,a)) tb_styles
@@ -756,7 +754,7 @@ let password = define_option mldonkey_gui_section
 let port = define_option mldonkey_gui_section 
     ["port"] 
     ( M.h_gui_port) 
-    int_option 4001
+    port_option 4001
 
 let hostname = define_option mldonkey_gui_section 
     ["hostname"] 
@@ -1043,7 +1041,6 @@ let table = [
   M.o_xpm_nbk_graphs_menu, (Nbk_graphs_menu_xpm.t, xpm_nbk_graphs_menu);
 
   M.o_xpm_about, (About_xpm.t, xpm_about);
-  M.o_xpm_im, (Im_xpm.t, xpm_im);
   M.o_xpm_settings, (Settings_xpm.t, xpm_settings);
   M.o_xpm_exit, (Exit_xpm.t, xpm_exit);
   M.o_xpm_gui, (Gui_xpm.t, xpm_gui);
@@ -1139,24 +1136,24 @@ let gdk_pix i =
     let (default, o) = List.assoc i table in
     match !!o with
       "" -> 
-	GDraw.pixmap_from_xpm_d ~data: default
-	  ~colormap: (Gdk.Color.get_system_colormap ())
-	  () 
+        GDraw.pixmap_from_xpm_d ~data: default
+          ~colormap: (Gdk.Color.get_system_colormap ())
+          () 
     | f ->
-	try
-	  GDraw.pixmap_from_xpm ~file: f
-	    ~colormap: (Gdk.Color.get_system_colormap ())
-	    () 
-	with
-	  _ ->
-	    GDraw.pixmap_from_xpm_d ~data: default
-	      ~colormap: (Gdk.Color.get_system_colormap ())
-	      () 
+        try
+          GDraw.pixmap_from_xpm ~file: f
+            ~colormap: (Gdk.Color.get_system_colormap ())
+            () 
+        with
+          _ ->
+            GDraw.pixmap_from_xpm_d ~data: default
+              ~colormap: (Gdk.Color.get_system_colormap ())
+              () 
   with
     Not_found ->
       GDraw.pixmap_from_xpm_d ~data: Trash_xpm.t
-	~colormap: (Gdk.Color.get_system_colormap ())
-	() 
+        ~colormap: (Gdk.Color.get_system_colormap ())
+        () 
       
 let pixmap i = GMisc.pixmap (gdk_pix i) ()
 
