@@ -397,11 +397,13 @@ let add_color_param ~p ~top ~(table : GPack.table) ?(h_label : GMisc.label optio
     let r = (Gdk.Color.red color) / 256 in
     let g = (Gdk.Color.green color) / 256 in
     let b = (Gdk.Color.blue color) / 256 in
-    let s = Printf.sprintf "%02X%02X%02X" r g b in
-    let _ =
-      for i = 1 to (String.length s) - 1 do
-        if s.[i] = ' ' then s.[i] <- '0'
-      done
+    let s =
+      let s = Bytes.unsafe_of_string @@ Printf.sprintf "%02X%02X%02X" r g b in
+      (* FIXME why start from 1 not 0? also seems this code is not needed, %02X takes care *)
+      for i = 1 to (Bytes.length s) - 1 do
+        if Bytes.get s i = ' ' then Bytes.set s i '0'
+      done;
+      Bytes.unsafe_to_string s
     in
     colv := "#" ^ s; 
     ("0x" ^ s ^ "FF")
@@ -499,19 +501,19 @@ let add_font_param ~p ~top ~(table : GPack.table) ?(h_label : GMisc.label option
     (event_wrap_widget ~w:hbox ~p ?h_label ());
   let f_sel () =
     let dialog = GWindow.font_selection_dialog
-	~title:(U.simple_utf8_of p.pref_label)
-	~modal:false
-	~show:true ()
+        ~title:(U.simple_utf8_of p.pref_label)
+        ~modal:false
+        ~show:true ()
     in
     dialog#selection#set_font_name !fontv;
     let wb_ok = dialog#ok_button in
     let wb_cancel = dialog#cancel_button in
     let _ = wb_ok#connect#clicked
-	(fun () -> 
-	  let font = dialog#selection#font_name in
+        (fun () -> 
+          let font = dialog#selection#font_name in
           set_font font;
-	  dialog#destroy ()
-	)
+          dialog#destroy ()
+        )
     in
     ignore (wb_cancel#connect#clicked dialog#destroy)
   in
