@@ -77,7 +77,6 @@ let table = [
   M.icon_menu_uploads, (Menu_uploads_svg.t, from_icons_dir M.icon_menu_uploads);
   M.icon_menu_console, (Menu_console_svg.t, from_icons_dir M.icon_menu_console);
   M.icon_menu_graph, (Menu_graph_svg.t, from_icons_dir M.icon_menu_graph);
-  M.icon_menu_im, (Menu_im_svg.t, from_icons_dir M.icon_menu_im);
   M.icon_menu_settings, (Menu_settings_svg.t, from_icons_dir M.icon_menu_settings);
   M.icon_menu_quit, (Menu_quit_svg.t, from_icons_dir M.icon_menu_quit);
   M.icon_menu_help, (Menu_help_svg.t, from_icons_dir M.icon_menu_help);
@@ -94,7 +93,6 @@ let table = [
   M.icon_menu_search_freedb, (Menu_search_freedb_svg.t, from_icons_dir M.icon_menu_search_freedb);
   M.icon_menu_search_imdb, (Menu_search_imdb_svg.t, from_icons_dir M.icon_menu_search_imdb);
   M.icon_menu_interfaces, (Menu_interfaces_svg.t, from_icons_dir M.icon_menu_interfaces);
-  M.icon_menu_mlchat, (Menu_mlchat_svg.t, from_icons_dir M.icon_menu_mlchat);
   M.icon_menu_tools, (Menu_tools_svg.t, from_icons_dir M.icon_menu_tools);
   M.icon_menu_others, (Menu_others_svg.t, from_icons_dir M.icon_menu_others);
 
@@ -243,7 +241,7 @@ open Zlib
 
 (* Return a pixbuf for a given svg data *)
 let pixb icon_name pixel_size =
-  let svg = uncompress_string icon_name in
+  let svg = Zlib2.uncompress_string icon_name in
   let z = float_of_int pixel_size /. 48. in
   let size_cb = (Rsvg.at_zoom z z) in
   let pb = Rsvg.render_from_string ~size_cb svg in
@@ -267,15 +265,15 @@ let pix_buf icon_name pixel_size ?(desat=false) () =
     let (default, o) = List.assoc icon_name table in
     match o with
       "" -> 
-	let pb = pixb default pixel_size in
+        let pb = pixb default pixel_size in
         saturate pb desat
     | f ->
-	try
-	  let pb = GdkPixbuf.from_file f in
+        try
+          let pb = GdkPixbuf.from_file f in
           saturate pb desat
-	with
-	  _ ->
-	    let pb = pixb default pixel_size in
+        with
+          _ ->
+            let pb = pixb default pixel_size in
             saturate pb desat
   with
     Not_found ->
@@ -442,16 +440,18 @@ let _ =
   done
 
 let normalize_availability avail =
-  let len = String.length avail in
+  let avail = Bytes.of_string avail in
+  let len = Bytes.length avail in
   for i = 0 to (len - 1) do
     if !!O.gtk_misc_use_availability_height
-      then if (int_of_char avail.[i]) > !!O.gtk_misc_availability_max
-        then avail.[i] <- (char_of_int !!O.gtk_misc_availability_max)
+      then if (int_of_char @@ Bytes.get avail i) > !!O.gtk_misc_availability_max
+        then Bytes.set avail i (char_of_int !!O.gtk_misc_availability_max)
         else ()
-      else if (int_of_char avail.[i]) > 1
-        then avail.[i] <- (char_of_int 1)
+      else if (int_of_char @@ Bytes.get avail i) > 1
+        then Bytes.set avail i (char_of_int 1)
         else ()
-  done
+  done;
+  Bytes.unsafe_to_string avail
 
 let get_availability_of availability chunks is_file =
   let height = 16 in
@@ -460,11 +460,8 @@ let get_availability_of availability chunks is_file =
     | Some chunks -> max 1 (VB.length chunks) in
   let avail =
     if is_file
-      then begin
-        let s = String.copy availability in
-        normalize_availability s;
-        s
-      end else availability
+      then normalize_availability availability
+      else availability
   in
   let key = (avail, chunks, is_file) in
   try
@@ -474,49 +471,49 @@ let get_availability_of availability chunks is_file =
       (if !!verbose then lprintf' "Creating new availability bar\n");
       let dest = GdkPixbuf.create ~width:nchunks ~height ~has_alpha:true () in
       (try
-	match chunks with
-	| None -> ()
-	| Some chunks ->
+        match chunks with
+        | None -> ()
+        | Some chunks ->
         for i = 0 to (nchunks - 1) do
           if is_file
           then 
-	    (match VB.get chunks i with
-	    | VB.State_complete | VB.State_verified ->
-		GdkPixbuf.copy_area ~dest ~dest_x:i ~dest_y:0 ~width:1 ~height ~src_x:0 ~src_y:0 color_green
-	    | VB.State_missing | VB.State_partial -> 
+            (match VB.get chunks i with
+            | VB.State_complete | VB.State_verified ->
+                GdkPixbuf.copy_area ~dest ~dest_x:i ~dest_y:0 ~width:1 ~height ~src_x:0 ~src_y:0 color_green
+            | VB.State_missing | VB.State_partial -> 
                 let h = int_of_char (avail.[i]) in
-		match h, VB.get chunks i with
-		| 0, VB.State_missing ->
-		    GdkPixbuf.copy_area ~dest ~dest_x:i ~dest_y:0 ~width:1 ~height ~src_x:0 ~src_y:0 color_red
-		| 0, _ ->
-		    GdkPixbuf.copy_area ~dest ~dest_x:i ~dest_y:0 ~width:1 ~height ~src_x:0 ~src_y:0 color_orange
-		| _, VB.State_missing ->
+                match h, VB.get chunks i with
+                | 0, VB.State_missing ->
+                    GdkPixbuf.copy_area ~dest ~dest_x:i ~dest_y:0 ~width:1 ~height ~src_x:0 ~src_y:0 color_red
+                | 0, _ ->
+                    GdkPixbuf.copy_area ~dest ~dest_x:i ~dest_y:0 ~width:1 ~height ~src_x:0 ~src_y:0 color_orange
+                | _, VB.State_missing ->
                     let color_blue = !color_blue_relative.(!!O.gtk_misc_availability_max - h) in
                     GdkPixbuf.copy_area ~dest ~dest_x:i ~dest_y:0 ~width:1 ~height ~src_x:0 ~src_y:0 color_blue
-		| _, _ ->
-		    GdkPixbuf.copy_area ~dest ~dest_x:i ~dest_y:0 ~width:1 ~height ~src_x:0 ~src_y:0 color_yellow
+                | _, _ ->
+                    GdkPixbuf.copy_area ~dest ~dest_x:i ~dest_y:0 ~width:1 ~height ~src_x:0 ~src_y:0 color_yellow
             )
           else 
-	    match int_of_char avail.[i] >= 49, VB.get chunks i with
-	    | true, VB.State_complete
-	    | true, VB.State_verified ->
-		GdkPixbuf.copy_area ~dest ~dest_x:i ~dest_y:0 ~width:1 ~height ~src_x:0 ~src_y:0 color_black
-	    | true, VB.State_missing ->
-		GdkPixbuf.copy_area ~dest ~dest_x:i ~dest_y:0 ~width:1 ~height ~src_x:0 ~src_y:0 color_green
-	    | true, VB.State_partial ->
-		GdkPixbuf.copy_area ~dest ~dest_x:i ~dest_y:0 ~width:1 ~height ~src_x:0 ~src_y:0 color_yellow
-	    | false, _ ->
-		GdkPixbuf.copy_area ~dest ~dest_x:i ~dest_y:0 ~width:1 ~height ~src_x:0 ~src_y:0 color_red
+            match int_of_char avail.[i] >= 49, VB.get chunks i with
+            | true, VB.State_complete
+            | true, VB.State_verified ->
+                GdkPixbuf.copy_area ~dest ~dest_x:i ~dest_y:0 ~width:1 ~height ~src_x:0 ~src_y:0 color_black
+            | true, VB.State_missing ->
+                GdkPixbuf.copy_area ~dest ~dest_x:i ~dest_y:0 ~width:1 ~height ~src_x:0 ~src_y:0 color_green
+            | true, VB.State_partial ->
+                GdkPixbuf.copy_area ~dest ~dest_x:i ~dest_y:0 ~width:1 ~height ~src_x:0 ~src_y:0 color_yellow
+            | false, _ ->
+                GdkPixbuf.copy_area ~dest ~dest_x:i ~dest_y:0 ~width:1 ~height ~src_x:0 ~src_y:0 color_red
         done;
 
       with _ ->
           if !!verbose then 
-	    lprintf' "Exception in creating avail_bar avail: %s chunks: %s file: %b\n" 
-	      avail 
-	      (match chunks with
-	      |	None -> ""
-	      | Some chunks -> VB.to_string chunks) 
-	      is_file;
+            lprintf' "Exception in creating avail_bar avail: %s chunks: %s file: %b\n" 
+              avail 
+              (match chunks with
+              |	None -> ""
+              | Some chunks -> VB.to_string chunks) 
+              is_file;
           for i = 0 to nchunks - 1 do
             GdkPixbuf.copy_area ~dest ~dest_x:i ~dest_y:0 ~width:1 ~height ~src_x:0 ~src_y:0 color_grey
           done);
@@ -535,8 +532,7 @@ let clean_avail_bars list =
            List.map (fun (avail, chunks, is_file) ->
              if is_file
                then begin
-                 let s = String.copy avail in
-                 normalize_availability s;
+                 let s = normalize_availability avail in
                  (s, chunks, is_file)
              end else (avail, chunks, is_file)
            ) list
