@@ -36,13 +36,13 @@ let client_port = define_option bittorrent_section ["client_port"]
 *)
 let generate_client_uid =
   let client_uid_from_version = "-ML" ^ Autoconf.current_version ^ "-" in
-  let client_uid_random_tail = String.create (20 - (String.length client_uid_from_version)) in
-  let sl_client_uid_random_tail = String.length client_uid_random_tail in
+  let client_uid_random_tail = Bytes.create (20 - (String.length client_uid_from_version)) in
+  let sl_client_uid_random_tail = Bytes.length client_uid_random_tail in
   if sl_client_uid_random_tail > 0  then
     for i = 0 to sl_client_uid_random_tail - 1 do
       client_uid_random_tail.[i] <- char_of_int (Random.int 256)
     done;
-  client_uid_from_version ^ client_uid_random_tail
+  client_uid_from_version ^ Bytes.unsafe_to_string client_uid_random_tail
 
 let client_uid = define_option bittorrent_section ["client_uid"]
   "The UID of this client"
