@@ -195,8 +195,8 @@ let new_client proto hostname port referer =
           client_referer = referer;
           client_port = port;
           client_country_code = None;
-	  client_total_downloaded = zero;
-	  client_session_downloaded = zero;
+          client_total_downloaded = zero;
+          client_session_downloaded = zero;
           client_reconnect = false;
           client_in_queues = [];
           client_connected_for = None;
@@ -207,7 +207,7 @@ let new_client proto hostname port referer =
           dummy_client_impl with
           impl_client_val = c;
           impl_client_ops = client_ops;
-	  impl_client_upload = None;
+          impl_client_upload = None;
         } in
       new_client impl;
       check_client_country_code c;
@@ -302,9 +302,9 @@ let client_name () =
   let name = !!global_login in
   if name != !old_client_name then  begin
       let len = String.length name in
-      ft_client_name := String.sub name 0 (min 32 len);
       old_client_name := name;
-      String2.replace_char !ft_client_name ' ' '_';
+      let name' = String.sub name 0 (min 32 len) in
+      ft_client_name := String2.replace_char name' ' ' '_';
     end;
   !ft_client_name
 
