@@ -264,7 +264,7 @@ let rec client_parse_header c gconn sock header =
 
             let old_downloaded = CommonSwarming.downloaded swarmer in
 
-            CommonSwarming.received up !counter_pos b.buf b.pos to_read_int;
+            CommonSwarming.received up !counter_pos (Bytes.unsafe_to_string b.buf) b.pos to_read_int;
             let new_downloaded = CommonSwarming.downloaded swarmer in
 
             c.client_total_downloaded <- c.client_total_downloaded ++ (new_downloaded -- old_downloaded);
