@@ -17,8 +17,6 @@
     Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *)
 
-open Md4
-open CommonOptions
 open Options
 
 let fileTP_ini = create_options_file "fileTP.ini"
