@@ -280,7 +280,7 @@ try_nick s sock;
       login_on_server s sock
       
   | OP.LoginAckReq mail ->
-      set_rtimeout sock DG.half_day;
+      set_rtimeout sock Date.half_day_in_secs;
       lprintf "*****  CONNECTED %s  ******\n" mail;
       set_server_state s (Connected (-1));
       connected_servers := s :: !connected_servers;
@@ -497,7 +497,7 @@ let ask_for_files () =
 let _ =
   server_ops.op_server_connect <- connect_server;
   server_ops.op_server_disconnect <- (fun s ->
-					  disconnect_server s Closed_by_user);
+                                          disconnect_server s Closed_by_user);
 (*
 (*  server_ops.op_server_query_users <- (fun s -> *)
       match s.server_sock with
