@@ -22,10 +22,10 @@ val input_byte: in_channel -> int
         (* Same as [Bzip2.input_char], but return the 8-bit integer representing
            the character.
            Raise [End_of_file] if no more compressed data is available. *)
-val input: in_channel -> string -> int -> int -> int
+val input: in_channel -> bytes -> int -> int -> int
         (* [input ic buf pos len] uncompresses up to [len] characters
            from the given channel [ic],
-           storing them in string [buf], starting at character number [pos].
+           storing them in buffer [buf], starting at character number [pos].
            It returns the actual number of characters read, between 0 and
            [len] (inclusive).
            A return value of 0 means that the end of file was reached.
@@ -38,10 +38,10 @@ val input: in_channel -> string -> int -> int -> int
            exactly [len] characters.)
            Exception [Invalid_argument "Bzip2.input"] is raised if
            [pos] and [len] do not designate a valid substring of [buf]. *)
-val really_input: in_channel -> string -> int -> int -> unit
+val really_input: in_channel -> bytes -> int -> int -> unit
         (* [really_input ic buf pos len] uncompresses [len] characters
            from the given channel, storing them in
-           string [buf], starting at character number [pos].
+           buffer [buf], starting at character number [pos].
            Raise [End_of_file] if fewer than [len] characters can be read.
            Raise [Invalid_argument "Bzip2.input"] if
            [pos] and [len] do not designate a valid substring of [buf]. *)
@@ -82,7 +82,7 @@ val output_char: out_channel -> char -> unit
 val output_byte: out_channel -> int -> unit
         (* Same as [Bzip2.output_char], but the output character is given
            by its code.  The given integer is taken modulo 256. *)
-val output: out_channel -> string -> int -> int -> unit
+val output: out_channel -> bytes -> int -> int -> unit
         (* [output oc buf pos len] compresses and writes [len] characters
            from string [buf], starting at offset [pos], and writes the
            compressed data to the channel [oc].
