@@ -116,19 +116,19 @@ let to_string filename =
   List.fold_left (fun file f -> f file) filename !to_strings
 
 let path_of_filename filename =
-  let filename = String.copy filename in
   let len = String.length filename in
+  let filename = Bytes.of_string filename in
   for i = 0 to len - 1 do
-    if filename.[i] = '\\' then filename.[i] <- '/';
+    if Bytes.get filename i = '\\' then Bytes.set filename i '/';
   done;
   let filename = 
-    if len > 2 && filename.[1]  = ':' &&
-      match filename.[0] with 
+    if len > 2 && Bytes.get filename 1 = ':' &&
+      match Bytes.get filename 0 with 
         'a' .. 'z' | 'A' .. 'Z' -> true
       | _ -> false then
-      Printf.sprintf "%s/%s" (String.sub filename 0 2) 
-      (String.sub filename 2 (len-2))
-    else filename
+      Printf.sprintf "%s/%s" (Bytes.sub_string filename 0 2) 
+      (Bytes.sub_string filename 2 (len-2))
+    else Bytes.unsafe_to_string filename
   in
   split_simplify filename '/'
 
@@ -142,18 +142,19 @@ let filesystem_compliant name fstype namemax =
   (* replace all illegal characters with a valid one.
      assumes all filesystems accept '_'s in filenames *)
   let escape_chars p filename =
-    let s = String.copy filename in
+    let s = Bytes.of_string filename in
     for i = 0 to String.length filename - 1 do
-      if p s.[i] then s.[i] <- '_'
+      if p (Bytes.get s i) then Bytes.set s i '_'
     done;
-    s in
+    Bytes.unsafe_to_string s
+  in
 
   (* remove all illegal characters at the beginning of filename *)
   let trim_left p filename =
     let len = String.length filename in
     let left =
       let rec aux i =
-	if i < len && p filename.[i] then aux (i+1) else i in
+        if i < len && p filename.[i] then aux (i+1) else i in
       aux 0 in
     if left = 0 then filename
     else
@@ -164,7 +165,7 @@ let filesystem_compliant name fstype namemax =
     let len = String.length filename in
     let right =
       let rec aux i =
-	if i > 0 && p filename.[i-1] then aux (i-1) else i in
+        if i > 0 && p filename.[i-1] then aux (i-1) else i in
       aux len in
     if right = len then filename
     else
@@ -182,9 +183,9 @@ let filesystem_compliant name fstype namemax =
     (* http://msdn.microsoft.com/library/default.asp?url=/library/en-us/fileio/fs/creating__deleting__and_maintaining_files.asp *)
     let windows_filter c = 
       minimal_filter c ||
-	match c with
-	  | '*' | '?' | '|' | ':' | '"' -> true
-	  | _ -> false in
+        match c with
+          | '*' | '?' | '|' | ':' | '"' -> true
+          | _ -> false in
 
     (* Windows has additional restrictions:
        - filenames cannot start with a '.' 
@@ -234,7 +235,7 @@ let filesystem_compliant name fstype namemax =
         if String.length ext > namemax then
           String.sub fs_checked_name 0 namemax
         else
-	  String.sub fs_checked_name 0 (namemax - (String.length ext)) ^ ext
+          String.sub fs_checked_name 0 (namemax - (String.length ext)) ^ ext
   in
   length_checked_name
 
