@@ -17,19 +17,6 @@
     Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *)
 
-open Printf2
-open Printf
-
 let to_string = function
-  | Unix.Unix_error (e, f, arg) -> sprintf "%s failed%s: %s" f (if arg = "" then "" else " on " ^ arg) (Unix.error_message e)
+  | Unix.Unix_error (e, f, arg) -> Printf.sprintf "%s failed%s: %s" f (if arg = "" then "" else " on " ^ arg) (Unix.error_message e)
   | exn -> Printexc.to_string exn
-
-let catch s f x =
-  try f x with
-    e -> 
-      lprintf_nl "Uncaught exception in %s: %s" s (to_string e)
-
-let catch2 s f x y =
-  try f x y with
-    e -> 
-      lprintf_nl "Uncaught exception in %s: %s" s (to_string e)
