@@ -14,7 +14,7 @@
 
     You should have received a copy of the GNU General Public License
     along with mldonkey; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 */
 
 /* Stub code to interface with libiconv
@@ -38,7 +38,8 @@
   #endif
   #ifdef HAVE_LIBCHARSET_H
     #include <libcharset.h>
-  #else
+  #endif
+  #ifdef HAVE_LANGINFO_H
     #include <langinfo.h>
   #endif
   #include <iconv.h>
@@ -572,10 +573,10 @@ utf8_validate (const char  *str,
 #define SUBLANG_AZERI_CYRILLIC 0x02
 #endif
 #ifndef SUBLANG_BENGALI_INDIA
-#define SUBLANG_BENGALI_INDIA 0x00
+#define SUBLANG_BENGALI_INDIA 0x01
 #endif
 #ifndef SUBLANG_BENGALI_BANGLADESH
-#define SUBLANG_BENGALI_BANGLADESH 0x01
+#define SUBLANG_BENGALI_BANGLADESH 0x02
 #endif
 #ifndef SUBLANG_CHINESE_MACAU
 #define SUBLANG_CHINESE_MACAU 0x05
@@ -668,16 +669,16 @@ utf8_validate (const char  *str,
 #define SUBLANG_NEPALI_INDIA 0x02
 #endif
 #ifndef SUBLANG_PUNJABI_INDIA
-#define SUBLANG_PUNJABI_INDIA 0x00
+#define SUBLANG_PUNJABI_INDIA 0x01
 #endif
 #ifndef SUBLANG_PUNJABI_PAKISTAN
-#define SUBLANG_PUNJABI_PAKISTAN 0x01
+#define SUBLANG_PUNJABI_PAKISTAN 0x02
 #endif
 #ifndef SUBLANG_ROMANIAN_ROMANIA
-#define SUBLANG_ROMANIAN_ROMANIA 0x00
+#define SUBLANG_ROMANIAN_ROMANIA 0x01
 #endif
 #ifndef SUBLANG_ROMANIAN_MOLDOVA
-#define SUBLANG_ROMANIAN_MOLDOVA 0x01
+#define SUBLANG_ROMANIAN_MOLDOVA 0x02
 #endif
 #ifndef SUBLANG_SERBIAN_LATIN
 #define SUBLANG_SERBIAN_LATIN 0x02
@@ -685,12 +686,12 @@ utf8_validate (const char  *str,
 #ifndef SUBLANG_SERBIAN_CYRILLIC
 #define SUBLANG_SERBIAN_CYRILLIC 0x03
 #endif
-#ifndef SUBLANG_SINDHI_INDIA
-#define SUBLANG_SINDHI_INDIA 0x00
-#endif
 #ifndef SUBLANG_SINDHI_PAKISTAN
 #define SUBLANG_SINDHI_PAKISTAN 0x01
 #endif
+#ifndef SUBLANG_SINDHI_AFGHANISTAN
+#define SUBLANG_SINDHI_AFGHANISTAN 0x02
+#endif
 #ifndef SUBLANG_SPANISH_GUATEMALA
 #define SUBLANG_SPANISH_GUATEMALA 0x04
 #endif
@@ -748,14 +749,14 @@ utf8_validate (const char  *str,
 #ifndef SUBLANG_TAMAZIGHT_ARABIC
 #define SUBLANG_TAMAZIGHT_ARABIC 0x01
 #endif
-#ifndef SUBLANG_TAMAZIGHT_LATIN
-#define SUBLANG_TAMAZIGHT_LATIN 0x02
+#ifndef SUBLANG_TAMAZIGHT_ALGERIA_LATIN
+#define SUBLANG_TAMAZIGHT_ALGERIA_LATIN 0x02
 #endif
 #ifndef SUBLANG_TIGRINYA_ETHIOPIA
-#define SUBLANG_TIGRINYA_ETHIOPIA 0x00
+#define SUBLANG_TIGRINYA_ETHIOPIA 0x01
 #endif
 #ifndef SUBLANG_TIGRINYA_ERITREA
-#define SUBLANG_TIGRINYA_ERITREA 0x01
+#define SUBLANG_TIGRINYA_ERITREA 0x02
 #endif
 #ifndef SUBLANG_URDU_PAKISTAN
 #define SUBLANG_URDU_PAKISTAN 0x01
@@ -1078,8 +1079,8 @@ ml_win32_get_default_language (void)
     case LANG_SINDHI: l = "sd";
       switch (sub)
 	{
-	case SUBLANG_SINDHI_INDIA: sl = "IN"; break;
 	case SUBLANG_SINDHI_PAKISTAN: sl = "PK"; break;
+	case SUBLANG_SINDHI_AFGHANISTAN: sl = "AF"; break;
 	}
       break;
     case LANG_SINHALESE: l = "si"; sl = "LK"; break;
@@ -1198,7 +1199,7 @@ ml_win32_get_default_language (void)
 
 size_t 
 ml_iconv (iconv_t cd,
-          const char    **inbuf,
+          char    **inbuf,
           size_t  *inbytes_left,
           char    **outbuf,
           size_t  *outbytes_left)
@@ -1206,6 +1207,10 @@ ml_iconv (iconv_t cd,
     return iconv (cd, inbuf, inbytes_left, outbuf, outbytes_left);
 }
 
+#ifndef EILSEQ
+#define EILSEQ ENOENT
+#endif
+
 char*
 ml_convert_with_iconv (const char *str,
                        size_t     len,
@@ -1234,7 +1239,7 @@ ml_convert_with_iconv (const char *str,
 
  again:
   
-  err = ml_iconv (cd, (const char **)&p, &inbytes_remaining, &outp, &outbytes_remaining);
+  err = ml_iconv (cd, (char**)&p, &inbytes_remaining, &outp, &outbytes_remaining);
 
   if (err == (size_t) -1)
     {
