@@ -45,7 +45,7 @@ module Base16 = struct
       else Char.chr (Char.code '0' + x)
         
     let to_string hash_length s =
-      let p = String.create (hash_length * 2) in
+      let p = Bytes.create (hash_length * 2) in
       for i = 0 to hash_length - 1 do
         let c = s.[i] in
         let n = int_of_char c in
@@ -54,7 +54,7 @@ module Base16 = struct
         p.[2 * i] <- hexa_digit i0;
         p.[2 * i+1] <- hexa_digit i1;
       done;
-      p
+      Bytes.unsafe_to_string p
     
     let hexa_digit_case upper x =
       if x >= 10 then Char.chr (Char.code (
@@ -62,7 +62,7 @@ module Base16 = struct
       else Char.chr (Char.code '0' + x)
 
     let to_string_case upper hash_length s =
-      let p = String.create (hash_length * 2) in
+      let p = Bytes.create (hash_length * 2) in
       for i = 0 to hash_length - 1 do
         let c = s.[i] in
         let n = int_of_char c in
@@ -71,7 +71,7 @@ module Base16 = struct
         p.[2 * i] <- hexa_digit_case upper i0;
         p.[2 * i+1] <- hexa_digit_case upper i1;
       done;
-      p
+      Bytes.unsafe_to_string p
     
     let digit_hexa c =
       let i = int_of_char c in
@@ -82,13 +82,13 @@ module Base16 = struct
     
     let of_string hash_length s =
       assert (String.length s = hash_length*2);
-      let p = String.create hash_length in
+      let p = Bytes.create hash_length in
       for i = 0 to hash_length - 1 do
         let c0 = s.[2*i] in
         let c1 = s.[2*i+1] in
         p.[i] <- char_of_int ((16 * digit_hexa c0) + digit_hexa c1);
       done;
-      p
+      Bytes.unsafe_to_string p
     
   end
 
@@ -103,32 +103,32 @@ module Base32 = struct
         'A' .. 'Z' -> int_of_char n - 65
       | 'a' .. 'z' -> int_of_char n - 97
       | _ -> (int_of_char n+26)-50
-    
+
     let of_string hash_length r =
       let len = String.length r in
       assert (len =  (hash_length * 8 + 4)/5);
-      let s = String.make hash_length '\000' in
+      let s = Bytes.make hash_length '\000' in
       for i = 0 to len - 1 do
         let pos = i * 5 in
         let byte = pos / 8 in
         let bit = pos mod 8 in
         let c = int5_of_char r.[i] in
-        if bit < 3 then 
+        if bit < 3 then
           let x = c lsl (3-bit) in
-          s.[byte] <- char_of_int (int_of_char s.[byte] lor x);
+          s.[byte] <- char_of_int (int_of_char (Bytes.get s byte) lor x);
         else
         let x = (c lsr (bit - 3)) land 0xff in
-        s.[byte] <- char_of_int (int_of_char s.[byte] lor x);
+        s.[byte] <- char_of_int (int_of_char (Bytes.get s byte) lor x);
         if byte+1 < hash_length then
           let y = (c lsl (11 - bit)) land 0xff in
-          s.[byte+1] <- char_of_int (int_of_char s.[byte+1] lor y);
+          s.[byte+1] <- char_of_int (int_of_char (Bytes.get s (byte+1)) lor y);
       done;
-      s    
-    
+      Bytes.unsafe_to_string s
+
     let to_string hash_length s =
       assert (String.length s = hash_length);
       let len = (hash_length * 8 + 4)/5 in
-      let r = String.create len in
+      let r = Bytes.create len in
       for i = 0 to len - 1 do
         let pos = i * 5 in
         let byte = pos / 8 in
@@ -145,16 +145,16 @@ module Base32 = struct
         let c = (x lsr (11 - bit)) land 0x1f in
         r.[i] <- char_of_int5 c
       done;
-      r
+      Bytes.unsafe_to_string r
 
     let char_of_int5 upper n =
       char_of_int (if n < 26 then (if upper then 65 else 97)+n else
           50+(n-26))
-    
+
     let to_string_case upper hash_length s =
       assert (String.length s = hash_length);
       let len = (hash_length * 8 + 4)/5 in
-      let r = String.create len in
+      let r = Bytes.create len in
       for i = 0 to len - 1 do
         let pos = i * 5 in
         let byte = pos / 8 in
@@ -171,7 +171,7 @@ module Base32 = struct
         let c = (x lsr (11 - bit)) land 0x1f in
         r.[i] <- char_of_int5 upper c
       done;
-      r
+      Bytes.unsafe_to_string r
       
   end
 
@@ -181,7 +181,7 @@ module Base6427 = struct
     let _ = assert (String.length base64tbl = 64)
     
     let to_string _ hashbin =
-      let hash64 = String.create 30 in
+      let hash64 = Bytes.create 30 in
       let hashbin n = int_of_char hashbin.[n] in
       hash64.[0] <- '=';
       let j = ref 1 in
@@ -198,16 +198,17 @@ module Base6427 = struct
         done
       done;
       hash64.[!j-1] <- '=';
-      String.sub hash64 0 !j
+      Bytes.sub_string hash64 0 !j
     
-    let base64tbl_inv = String.create 126
-    let _ = 
+    let base64tbl_inv =
+      let table = Bytes.create 126 in
       for i = 0 to 63 do
-        base64tbl_inv.[int_of_char base64tbl.[i]] <- char_of_int i
-      done
+        table.[int_of_char base64tbl.[i]] <- char_of_int i
+      done;
+      Bytes.unsafe_to_string table
     
     let of_string _ hash64 =
-      let hashbin = String.make 20 '\000' in
+      let hashbin = Bytes.make 20 '\000' in
       let hash64 n = 
         let c = hash64.[n] in
         int_of_char base64tbl_inv.[int_of_char c]
@@ -233,7 +234,7 @@ module Base6427 = struct
         hashbin.[!j+1] <- char_of_int ((!tmp lsr  8) land 0xff);
         j := !j + 2;
       done;
-      hashbin
+      Bytes.unsafe_to_string hashbin
       
     let to_string_case _ = to_string
   end
@@ -291,12 +292,12 @@ module Make(M: sig
       val hash_name : string
       
 (* [unsafe_string digest string string_len] *)
-      val unsafe_string : string -> string -> int -> unit
+      val unsafe_string : bytes -> string -> int -> unit
           
 (* [unsafe_file digest filename filesize] *)
-        val unsafe_file : string -> string -> int64 -> unit
+      val unsafe_file : bytes -> string -> int64 -> unit
 (* [unsafe_string digest file_fd offset len] *)
-      val digest_subfile : string -> Unix.file_descr -> int64 -> int64 -> unit 
+      val digest_subfile : bytes -> Unix.file_descr -> int64 -> int64 -> unit 
     
       module Base : Base
     end) = struct
@@ -314,13 +315,13 @@ module Make(M: sig
 
     let string s =
       let len = String.length s in
-      let digest = String.create hash_length in
+      let digest = Bytes.create hash_length in
       unsafe_string digest s len;
-      digest
+      Bytes.unsafe_to_string digest
 
     let to_bits s =
       let len = String.length s in
-      let digest = String.create (8*len) in
+      let digest = Bytes.create (8*len) in
       for i = 0 to len-1 do
         let c = int_of_char s.[i] in
         for j = 7 downto 0 do
@@ -329,39 +330,39 @@ module Make(M: sig
             
         done
       done;
-      digest
+      Bytes.unsafe_to_string digest
       
-    external xor_c : t -> t -> t -> unit = "md4_xor" "noalloc"
+    external xor_c : t -> t -> bytes -> unit = "md4_xor" "noalloc"
     
     let xor m1 m2 =
-      let m3 = String.create hash_length in
+      let m3 = Bytes.create hash_length in
       xor_c m1 m2 m3;
-      m3
+      Bytes.unsafe_to_string m3
     
     let file s =
-      let digest = String.create hash_length in
+      let digest = Bytes.create hash_length in
       let file_size = Unix32.getsize s in
       unsafe_file digest s file_size;
-      digest
+      Bytes.unsafe_to_string digest
     
     let digest_subfile fd pos len =
-      let digest = String.create hash_length in
+      let digest = Bytes.create hash_length in
       Unix32.apply_on_chunk fd pos len 
         (fun fd pos ->
           digest_subfile digest fd pos len);
-      digest
+      Bytes.unsafe_to_string digest
     
-    let create () =  String.create hash_length
+    let create () = String.make hash_length '\x00'
     
     let direct_to_string s = s
     let direct_of_string s = s
     
     let random () =
-      let s = create () in
+      let s = Bytes.create hash_length in
       for i = 0 to hash_length - 1 do
         s.[i] <- char_of_int (Random.int 256)
       done;
-      s
+      Bytes.unsafe_to_string s
     
     let of_string = Base.of_string hash_length
     let to_string = Base.to_string hash_length
@@ -397,9 +398,9 @@ module Md4 = Make(struct
       let hash_length = 16
       let hash_name = "Md4"        
       
-      external unsafe_string : string -> string -> int -> unit = "md4_unsafe_string"
-      external unsafe_file : string -> string -> int64 -> unit = "md4_unsafe_file"
-      external digest_subfile : string -> Unix.file_descr -> int64 -> int64 -> unit =
+      external unsafe_string : bytes -> string -> int -> unit = "md4_unsafe_string"
+      external unsafe_file : bytes -> string -> int64 -> unit = "md4_unsafe_file"
+      external digest_subfile : bytes -> Unix.file_descr -> int64 -> int64 -> unit =
         "md4_unsafe64_fd"
   
       module Base = Base16
@@ -409,9 +410,9 @@ module Md5 = Make(struct
       let hash_length = 16
       let hash_name = "Md5"        
       
-      external unsafe_string : string -> string -> int -> unit = "md5_unsafe_string"
-      external unsafe_file : string -> string -> int64 -> unit = "md5_unsafe_file"
-      external digest_subfile : string -> Unix.file_descr -> int64 -> int64 -> unit =
+      external unsafe_string : bytes -> string -> int -> unit = "md5_unsafe_string"
+      external unsafe_file : bytes -> string -> int64 -> unit = "md5_unsafe_file"
+      external digest_subfile : bytes -> Unix.file_descr -> int64 -> int64 -> unit =
         "md5_unsafe64_fd"
     
       module Base = Base16
@@ -421,9 +422,9 @@ module PreSha1 = Make(struct
       let hash_length = 20
       let hash_name = "Sha1"        
       
-      external unsafe_string : string -> string -> int -> unit = "sha1_unsafe_string"
-      external unsafe_file : string -> string -> int64 -> unit = "sha1_unsafe_file"
-      external digest_subfile : string -> Unix.file_descr -> int64 -> int64 -> unit =
+      external unsafe_string : bytes -> string -> int -> unit = "sha1_unsafe_string"
+      external unsafe_file : bytes -> string -> int64 -> unit = "sha1_unsafe_file"
+      external digest_subfile : bytes -> Unix.file_descr -> int64 -> int64 -> unit =
         "sha1_unsafe64_fd"
       
       module Base = Base32
@@ -464,7 +465,7 @@ module Tiger = Make(struct
       let hash_length = 24
       let hash_name = "Tiger"        
       
-      external unsafe_string : string -> string -> int -> unit = 
+      external unsafe_string : bytes -> string -> int -> unit = 
         "tiger_unsafe_string"
         
       let unsafe_file digest filename = 
@@ -481,8 +482,8 @@ module PreTigerTree = Make(struct
       let hash_length = 24
       let hash_name = "TigerTree"        
       
-      external unsafe_string : string -> string -> int -> unit = "tigertree_unsafe_string"
-      external digest_subfile : string -> Unix.file_descr -> int64 -> int64 -> unit =
+      external unsafe_string : bytes -> string -> int -> unit = "tigertree_unsafe_string"
+      external digest_subfile : bytes -> Unix.file_descr -> int64 -> int64 -> unit =
         "tigertree_unsafe64_fd"
       
       let unsafe_file digest filename file_size = 
@@ -530,10 +531,10 @@ module PreMd5Ext = Make(struct
       let hash_length = 20
       let hash_name = "Md5Ext"        
 
-      external unsafe_string : string -> string -> int -> unit =
+      external unsafe_string : bytes -> string -> int -> unit =
         "fst_hash_string_ml"
         
-      external unsafe_file : string -> string -> int64 -> unit = "fst_hash_file_ml"
+      external unsafe_file : bytes -> string -> int64 -> unit = "fst_hash_file_ml"
       let digest_subfile _ _ _ _ = 
         failwith "Md5Ext.digest_subfile not implemented"
     
