@@ -64,7 +64,7 @@ let decode64 s =
     | _ -> failwith "not a base64 string" in
   let len = String.length s in
   let len_res = len * 3 / 4 in
-  let res = String.create len_res in
+  let res = Bytes.create len_res in
   for i=0 to len/4 - 1 do
     let i1 = 4*i and i2 = 3*i in
     let v1 = (val64 s.[i1]) lsl 18 in
@@ -80,7 +80,7 @@ let decode64 s =
     if s.[len-1] = '=' then
       if s.[len-2] = '=' then 2 else 1
     else 0 in
-  String.sub res 0 (len_res - nb_cut)
+  Bytes.sub_string res 0 (len_res - nb_cut)
 
 
 let debug = ref false
@@ -793,17 +793,17 @@ let request_handler config sock nread =
   let rec iter i =
     let end_pos = b.pos + b.len in
     if i < end_pos then
-      if b.buf.[i] = '\n' && i <= end_pos - 2 then
-        let c = b.buf.[i+1] in
+      if Bytes.get b.buf i = '\n' && i <= end_pos - 2 then
+        let c = Bytes.get b.buf (i+1) in
         if c = '\n' then
           let len = i + 2 - b.pos in
-          let header = String.sub b.buf b.pos len in
+          let header = Bytes.sub_string b.buf b.pos len in
           buf_used b len;
           manage config sock header
         else
-        if c = '\r' && i <= end_pos - 3 && b.buf.[i+2] = '\n' then
+        if c = '\r' && i <= end_pos - 3 && Bytes.get b.buf (i+2) = '\n' then
           let len = i + 3 - b.pos in
-          let header = String.sub b.buf b.pos len in
+          let header = Bytes.sub_string b.buf b.pos len in
           buf_used b len;
           manage config sock header
         else
@@ -830,16 +830,16 @@ let handler config t event =
     (* check here if ip is OK *)
       let from_ip = Ip.of_inet_addr from_ip in
       let ip_is_allowed from_ip =
-	Ip_set.match_ip config.addrs from_ip
+        Ip_set.match_ip config.addrs from_ip
       in
       let ip_is_blocked from_ip =
-	if config.use_ip_block_list then
-	  match !Ip.banned (from_ip, None) with
+        if config.use_ip_block_list then
+          match !Ip.banned (from_ip, None) with
             None -> false
            | Some reason -> lprintf_nl "%s:%d blocked: %s"
                (Ip.to_string from_ip) from_port reason; true
         else
-	  false
+          false
       in 
       if ip_is_allowed from_ip && not (ip_is_blocked from_ip) then
         let token = create_token unlimited_connection_manager in
@@ -854,15 +854,15 @@ let handler config t event =
       else begin
         lprintf_nl "connection from %s rejected (%s)"
           (Ip.to_string from_ip)
-	  (if ip_is_blocked from_ip then "IP is blocked" else "see allowed_ips setting");
+          (if ip_is_blocked from_ip then "IP is blocked" else "see allowed_ips setting");
         let token = create_token unlimited_connection_manager in
         let sock = TcpBufferedSocket.create_simple token "http connection" s in
-	let s1,s2,_ = error_page
+        let s1,s2,_ = error_page
       (if not (ip_is_allowed from_ip) then Not_allowed from_ip else Blocked from_ip)
-	    (TcpBufferedSocket.my_ip sock)
-	    config.port
-	in
-	TcpBufferedSocket.write_string sock (Printf.sprintf "%s\n%s" s1 s2);
+            (TcpBufferedSocket.my_ip sock)
+            config.port
+        in
+        TcpBufferedSocket.write_string sock (Printf.sprintf "%s\n%s" s1 s2);
         shutdown sock Closed_connect_failed;
         Unix.close s
       end
