@@ -120,14 +120,14 @@ let make_mail mail new_style =
   in
   let mail_date = Date.mail_string (Unix.time ()) in
   let addr = mail_address new_style in
-	Printf.sprintf 
-	"From: mldonkey %s\r\nTo: %s\r\n%s%s\r\nMIME-Version: 1.0\r\nContent-Type: text/plain; charset=utf-8\r\nDate: %s\r\n\r\n%s"
-	(addr mail.mail_from)
-	(addr mail_to)
-	(match mail_cc with [] -> "" | l -> Printf.sprintf "Cc: %s\r\n" (String.concat ", " (List.map addr l)))
-	(rfc2047_encode "Subject: " "utf-8" mail.mail_subject)
-	mail_date
-	mail.mail_body
+        Printf.sprintf 
+        "From: mldonkey %s\r\nTo: %s\r\n%s%s\r\nMIME-Version: 1.0\r\nContent-Type: text/plain; charset=utf-8\r\nDate: %s\r\n\r\n%s"
+        (addr mail.mail_from)
+        (addr mail_to)
+        (match mail_cc with [] -> "" | l -> Printf.sprintf "Cc: %s\r\n" (String.concat ", " (List.map addr l)))
+        (rfc2047_encode "Subject: " "utf-8" mail.mail_subject)
+        mail_date
+        mail.mail_body
 
 let canon_addr s = 
   let len = String.length s in
@@ -144,11 +144,11 @@ let canon_addr s =
 
 let string_xor s1 s2 =
   assert (String.length s1 = String.length s2);
-  let s = String.create (String.length s1) in
-  for i = 0 to String.length s - 1 do
+  let s = Bytes.create (String.length s1) in
+  for i = 0 to Bytes.length s - 1 do
     s.[i] <- Char.chr (Char.code s1.[i] lxor Char.code s2.[i]);
   done;
-  s
+  Bytes.unsafe_to_string s
 
 (* HMAC-MD5, RFC 2104 *)
 let hmac_md5 =
@@ -157,8 +157,9 @@ let hmac_md5 =
   let md5 s = Md5.direct_to_string (Md5.string s) in
   fun secret challenge ->
     let secret = if String.length secret > 64 then md5 secret else secret in
-    let k = String.make 64 '\x00' in
+    let k = Bytes.make 64 '\x00' in
     String.blit secret 0 k 0 (String.length secret);
+    let k = Bytes.unsafe_to_string k in
     md5 (string_xor k opad ^ md5 (string_xor k ipad ^ challenge))
 
 let sendmail smtp_server smtp_port new_style mail =
