@@ -81,7 +81,7 @@ and connection_manager = {
   }
 
 type buf = {
-    mutable buf : string;
+    mutable buf : bytes;
     mutable pos : int;
     mutable len : int;
     mutable max_buf_size : int;
@@ -352,28 +352,28 @@ let min_buffer_read = 2000
 let min_read_size = min_buffer_read - 100
 
 let old_strings_size = 20
-let old_strings = Array.make old_strings_size ""
+let old_strings = Array.make old_strings_size Bytes.empty
 let old_strings_len = ref 0
 
 let new_string () =
   if !old_strings_len > 0 then begin
       decr old_strings_len;
       let s = old_strings.(!old_strings_len) in
-      old_strings.(!old_strings_len) <- "";
+      old_strings.(!old_strings_len) <- Bytes.empty;
       s
     end else
-    String.create min_buffer_read
+    Bytes.create min_buffer_read
 
 let delete_string s =
   if !old_strings_len < old_strings_size &&
-    String.length s = min_buffer_read then begin
+    Bytes.length s = min_buffer_read then begin
       old_strings.(!old_strings_len) <- s;
       incr old_strings_len;
     end
 
 let buf_create max =
   {
-    buf = "";
+    buf = Bytes.empty;
     pos = 0;
     len = 0;
     max_buf_size = max;
@@ -386,14 +386,14 @@ let buf_used b nused =
     ( b.len <- 0;
       b.pos <- 0;
       delete_string b.buf;
-      b.buf <- "";
+      b.buf <- Bytes.empty;
       )
   else
     (b.len <- b.len - nused; b.pos <- b.pos + nused)
 
 let buf_size  t =
-  (String.length t.rbuf.buf),
-  (String.length t.wbuf.buf)
+  (Bytes.length t.rbuf.buf),
+  (Bytes.length t.wbuf.buf)
 
 (*************************************************************************)
 (*                                                                       *)
@@ -404,17 +404,17 @@ let buf_size  t =
 let buf_add t b s pos1 len =
   let curpos = b.pos + b.len in
   let max_len =
-    if b.buf = "" then
+    if Bytes.length b.buf = 0 then
       begin
         b.buf <- new_string ();
         min_buffer_read
       end else
-      String.length b.buf in
+      Bytes.length b.buf in
   if max_len - curpos < len then (* resize before blit *)
     if b.len + len < max_len then (* just move to 0 *)
       begin
-        String.blit b.buf b.pos b.buf 0 b.len;
-        String.blit s pos1 b.buf b.len len;
+        Bytes.blit b.buf b.pos b.buf 0 b.len;
+        Bytes.blit s pos1 b.buf b.len len;
         b.len <- b.len + len;
         b.pos <- 0;
       end
@@ -424,7 +424,7 @@ let buf_add t b s pos1 len =
 
         lprintf "MESSAGE: [";
         for i = pos1 to pos1 + (min len 20) - 1 do
-          lprintf "(%d)" (int_of_char s.[i]);
+          lprintf "(%d)" (int_of_char (Bytes.get s i));
         done;
         if len > 20 then lprintf "...";
         lprintf "]\n";
@@ -438,8 +438,8 @@ let buf_add t b s pos1 len =
 (*    if t.monitored then
       (lprintf "Allocate new for %d\n" len; ); *)
     let new_buf = String.create new_len in
-    String.blit b.buf b.pos new_buf 0 b.len;
-    String.blit s pos1 new_buf b.len len;
+    Bytes.blit b.buf b.pos new_buf 0 b.len;
+    Bytes.blit s pos1 new_buf b.len len;
     b.len <- b.len + len;
     b.pos <- 0;
     if max_len = min_buffer_read then delete_string b.buf;
@@ -447,7 +447,7 @@ let buf_add t b s pos1 len =
       (lprintf "new buffer allocated\n"; ); *)
     b.buf <- new_buf
   else begin
-      String.blit s pos1 b.buf curpos len;
+      Bytes.blit s pos1 b.buf curpos len;
       b.len <- b.len + len
     end
 
@@ -494,8 +494,8 @@ end;
         t.closing <- true;
         delete_string t.rbuf.buf;
         delete_string t.wbuf.buf;
-        t.rbuf.buf <- "";
-        t.wbuf.buf <- "";
+        t.rbuf.buf <- Bytes.empty;
+        t.wbuf.buf <- Bytes.empty;
         if t.nread > 0 then begin
             register_upload t 0;
             forecast_download t 0;
@@ -614,7 +614,7 @@ let can_read_handler t sock max_len =
       big_buffer, 0, big_buffer_len
     else
     let can_write_in_buffer =
-      if b.buf = "" then
+      if Bytes.length b.buf = 0 then
         if b.min_buf_size <= min_buffer_read then begin
             b.buf <- new_string ();
             min_buffer_read
@@ -623,7 +623,7 @@ let can_read_handler t sock max_len =
             b.min_buf_size
           end
       else
-      let buf_len = String.length b.buf in
+      let buf_len = Bytes.length b.buf in
       if buf_len - curpos < min_read_size then
         if b.len + min_read_size > b.max_buf_size then
           (
@@ -635,7 +635,7 @@ let can_read_handler t sock max_len =
         else
         if b.len + min_read_size < buf_len then
           (
-            String.blit b.buf b.pos b.buf 0 b.len;
+            Bytes.blit b.buf b.pos b.buf 0 b.len;
             b.pos <- 0;
             buf_len - b.len
           )
@@ -645,7 +645,7 @@ let can_read_handler t sock max_len =
               (2 * buf_len) (b.len + min_read_size)) b.max_buf_size
         in
         let new_buf = String.create new_len in
-        String.blit b.buf b.pos new_buf 0 b.len;
+        Bytes.blit b.buf b.pos new_buf 0 b.len;
         b.pos <- 0;
         b.buf <- new_buf;
         new_len - b.len
@@ -662,7 +662,7 @@ let can_read_handler t sock max_len =
 (*        lprintf "Unix.read %d/%d/%d\n"  (String.length b.buf) (b.pos + b.len) can_read;  *)
         Unix.read (fd sock) buffer buffer_pos can_read;
 
-	
+        
       with
         Unix.Unix_error((Unix.EWOULDBLOCK | Unix.EAGAIN), _,_) as e -> raise e
       | e ->
@@ -774,7 +774,7 @@ let can_write_handler t sock max_len =
         if b.len = 0 then begin
             b.pos <- 0;
             delete_string b.buf;
-            b.buf <- "";
+            b.buf <- Bytes.empty;
           end
       with
         Unix.Unix_error((Unix.EWOULDBLOCK | Unix.EAGAIN ), _,_) as e -> raise e
@@ -1052,19 +1052,19 @@ let set_reader t f =
           let rcode, rstr, rstr_end =
             try
               let rcode_pos = 8 (*String.index_from b.buf b.pos ' '*) in
-              let rcode = String.sub b.buf (rcode_pos+1) 3 in
+              let rcode = Bytes.sub b.buf (rcode_pos+1) 3 in
               let rstr_pos = 12 (*String.index_from b.buf (rcode_pos+1) ' '*) in
-              let rstr_end = String.index_from b.buf (rstr_pos+1) '\n' in
-              let rstr = String.sub b.buf (rstr_pos+1) (rstr_end-rstr_pos-1) in
+              let rstr_end = Bytes.index_from b.buf (rstr_pos+1) '\n' in
+              let rstr = Bytes.sub b.buf (rstr_pos+1) (rstr_end-rstr_pos-1) in
               lprintf "From proxy for %s: %s %s\n"
-                (Ip.to_string sock.host) rcode rstr;
+                (Ip.to_string sock.host) (Bytes.unsafe_to_string rcode) (Bytes.unsafe_to_string rstr);
               rcode, rstr, rstr_end
             with _ ->
-                "", "", 0
+                Bytes.empty, Bytes.empty, 0
           in
-          (match rcode with
+          (match (Bytes.to_string rcode) with
               "200" -> (*lprintf "Connect to client via proxy ok\n";*)
-                let pos = String.index_from b.buf (rstr_end+1) '\n' in
+                let pos = Bytes.index_from b.buf (rstr_end+1) '\n' in
                 let used = pos + 1 - b.pos in
                 sock_used sock used;
                 if nread != used then
@@ -1147,14 +1147,14 @@ let dump_socket t buf =
   print_socket buf t.sock_in;
   print_socket buf t.sock_out;
   Printf.bprintf buf "rbuf: %d/%d wbuf: %d/%d\n" t.rbuf.len
-    (String.length t.rbuf.buf) t.wbuf.len (String.length t.wbuf.buf)
+    (Bytes.length t.rbuf.buf) t.wbuf.len (Bytes.length t.wbuf.buf)
 
 let stats buf t =
   BasicSocket.stats buf t.sock_in;
   BasicSocket.stats buf t.sock_out;
-  Printf.bprintf buf "  rbuf size: %d/%d\n" (String.length t.rbuf.buf)
+  Printf.bprintf buf "  rbuf size: %d/%d\n" (Bytes.length t.rbuf.buf)
   t.rbuf.max_buf_size;
-  Printf.bprintf buf "  wbuf size: %d/%d\n" (String.length t.wbuf.buf)
+  Printf.bprintf buf "  wbuf size: %d/%d\n" (Bytes.length t.wbuf.buf)
   t.wbuf.max_buf_size
 
 (*************************************************************************)
@@ -1354,7 +1354,7 @@ let connect token name host port handler =
         end;
         Printf.bprintf buf "User-Agent: MLdonkey/%s\n" Autoconf.current_version;
         Printf.bprintf buf "\n";
-        ignore (MlUnix.write s (Buffer.contents buf) 0 (Buffer.length buf))
+        ignore (MlUnix.write s (Buffer.to_bytes buf) 0 (Buffer.length buf))
       end;
     let t = create token name s handler in
 
@@ -1390,7 +1390,7 @@ let connect token name host port handler =
         t
     | Unix.Unix_error (Unix.ENETUNREACH,_,_) as e ->
         (* log nothing here, but later in donkeyClient.ml *)
-	close t Closed_connect_failed;
+        close t Closed_connect_failed;
         raise e
     | e ->
         close t Closed_connect_failed;
@@ -1461,12 +1461,12 @@ open LittleEndian
 let internal_buf = Buffer.create 17000
 
 let simple_send_buf buf sock =
-  let s = Buffer.contents buf in
+  let s = Buffer.to_bytes buf in
   Buffer.reset buf;
   buf_int8 buf 228;
-  let len = String.length s in
+  let len = Bytes.length s in
   buf_int buf len;
-  write sock (Buffer.contents buf) 0 5;
+  write sock (Buffer.to_bytes buf) 0 5;
   write sock s 0 len
 
 let value_send sock m =
@@ -1479,11 +1479,11 @@ let value_handler f sock nread =
   let b = buf sock in
   try
     while b.len >= 5 do
-      let msg_len = get_int b.buf (b.pos+1) in
+      let msg_len = get_int (Bytes.unsafe_to_string b.buf) (b.pos+1) in
       if b.len >= 5 + msg_len then
         begin
-          let s = String.sub b.buf (b.pos+5) msg_len in
-          let t = Marshal.from_string  s 0 in
+          let s = Bytes.sub b.buf (b.pos+5) msg_len in
+          let t = Marshal.from_bytes  s 0 in
           buf_used b  (msg_len + 5);
           f t sock;
           ()
@@ -1618,14 +1618,15 @@ let write t s pos len =
       _to_deflate t;
       buf_add t wbuf s pos len
 
+let write_bytes t s = write t s 0 (Bytes.length s)
+let write_string t s = write_bytes t (Bytes.unsafe_of_string s)
+
 (*************************************************************************)
 (*                                                                       *)
 (*                         MAIN                                          *)
 (*                                                                       *)
 (*************************************************************************)
 
-let write_string t s = write t s 0 (String.length s)
-
 let _ =
   add_bandwidth_second_timer (fun _ ->
       reset_bandwidth_controlers ();
@@ -1800,7 +1801,7 @@ let output_buffered t = t.wbuf.len
 let _ =
   Heap.add_memstat "tcpBufferedSocket" (fun level buf ->
       Printf.bprintf buf "  %d latencies\n" (Hashtbl.length latencies);
-      Printf.bprintf buf "  String.length big_buffer: %d\n" (String.length big_buffer);
+      Printf.bprintf buf "  String.length big_buffer: %d\n" (Bytes.length big_buffer);
       Printf.bprintf buf "  connection_managers: %d\n" (List.length !connection_managers);
       Printf.bprintf buf "  read_bandwidth_controlers: %d\n" (List.length !read_bandwidth_controlers);
       Printf.bprintf buf "  write_bandwidth_controlers: %d\n" (List.length !write_bandwidth_controlers);
